OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Agregado a los favoritos",
    "Removed from favorites" : "Eliminado de los favoritos",
    "You added {file} to your favorites" : "Agregaste {file} a tus favoritos",
    "You removed {file} from your favorites" : "Eliminaste {file} de tus favoritos",
    "Favorites" : "Favoritos",
    "File changes" : "Cambios al archivo",
    "Created by {user}" : "Creado por {user}",
    "Changed by {user}" : "Cambiado por {user}",
    "Deleted by {user}" : "Borrado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renombrado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote account\"" : "\"cuenta remota\"",
    "You created {file}" : "Creaste {file}",
    "You created an encrypted file in {file}" : "Creaste un archivo encriptado en {file}",
    "{user} created {file}" : "{user} creó {file}",
    "{user} created an encrypted file in {file}" : "{user} creó un archivo encriptado en {file}",
    "{file} was created in a public folder" : "{file} fue creado en una carpeta pública",
    "You changed {file}" : "Cambiaste {file}",
    "You changed an encrypted file in {file}" : "Cambiaste un archivo encriptado en {file}",
    "{user} changed {file}" : "{user} cambió {file}",
    "{user} changed an encrypted file in {file}" : "{user} cambió un archivo encriptado en {file}",
    "You deleted {file}" : "Borraste {file}",
    "You deleted an encrypted file in {file}" : "Borraste un archivo encriptado en {file}",
    "{user} deleted {file}" : "{user} borró {file}",
    "{user} deleted an encrypted file in {file}" : "{user} borró un archivo encriptado en {file}",
    "You restored {file}" : "Restauraste {file}",
    "{user} restored {file}" : "{user} restauró {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Has renombrado {oldfile} (oculto) a {newfile} (oculto)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Has renombrado {oldfile} (oculto) a {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Has renombrado {oldfile} a {newfile} (oculto)",
    "You renamed {oldfile} to {newfile}" : "Renombraste {oldfile} como {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} renombró {oldfile} (oculto) a {newfile} (oculto)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} renombró {oldfile} (oculto) a {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} renombró {oldfile} a {newfile} (oculto)",
    "{user} renamed {oldfile} to {newfile}" : "{user} renombró {oldfile} como {newfile}",
    "You moved {oldfile} to {newfile}" : "Moviste {oldfile} a {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} movió {oldfile} a {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un archivo ha sido agregado o eliminado de tus <strong>favoritos</strong>",
    "Files" : "Archivos",
    "A file or folder has been <strong>changed</strong>" : "Un archivo o carpeta ha sido <strong>cambiado</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Un archivo o carpeta favorito ha sido <strong>cambiado</strong>",
    "Failed to authorize" : "Fallo al autorizar",
    "Invalid folder path" : "Ruta de carpeta inválida",
    "Folder not found" : "No se encontró la carpeta",
    "No favorites" : "No hay favoritos",
    "Accept" : "Aceptar",
    "Reject" : "Rechazar",
    "Incoming ownership transfer from {user}" : "Solicitud de transferencia de propiedad entrante de {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "¿Desea aceptar {path}?\n\nNota: El proceso de transferencia tras aceptar podría tardar hasta 1 hora.",
    "Ownership transfer denied" : "Transferencia de propiedad denegada",
    "Your ownership transfer of {path} was denied by {user}." : "Su transferencia de propiedad de {path} fue denegada por {user}.",
    "Ownership transfer failed" : "Fallo al transferir la propiedad",
    "Your ownership transfer of {path} to {user} failed." : "Ha fallado su transferencia de propiedad de {path} a {user}.",
    "The ownership transfer of {path} from {user} failed." : "Ha fallado la transferencia de propiedad de {path} desde {user}.",
    "Ownership transfer done" : "Transferencia de propiedad realizada",
    "Your ownership transfer of {path} to {user} has completed." : "Se ha completado su transferencia de propiedad de {path} a {user}.",
    "The ownership transfer of {path} from {user} has completed." : "Se ha completado la transferencia de propiedad de {path} a {user}.",
    "in %s" : "en %s",
    "Transferred from %1$s on %2$s" : "Transfirió desde %1$s en %2$s",
    "File Management" : "Administración de Archivos",
    "Home" : "Inicio",
    "Target folder does not exist any more" : "La carpeta destino ya no existe",
    "Reload current directory" : "Recargar el directorio actual",
    "Go to the \"{dir}\" directory" : "Ir al directorio \"{dir}\"",
    "Current directory path" : "Dirección del directorio actual",
    "Your have used your space quota and cannot upload files anymore" : "Ha utilizado su cuota de espacio y ya no puede subir más archivos",
    "Drag and drop files here to upload" : "Arrastre y suelte los archivos aquí para subirlos",
    "Favorite" : "Favorito",
    "Back" : "Atrás",
    "Toggle selection for file \"{displayName}\"" : "Alternar selección para archivo \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Alternar selección para la carpeta \"{displayName}\"",
    "File is loading" : "El archivo se está cargando",
    "Folder is loading" : "La carpeta se está cargando",
    "Filename" : "Nombre del archivo",
    "Folder name" : "Nombre de la carpeta",
    "This node is unavailable" : "Este nodo no está disponible",
    "Another entry with the same name already exists." : "Ya existe otra entrada con el mismo nombre.",
    "Invalid filename." : "Nombre de archivo inválido",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Renombrado \"{oldName}\" a \"{newName}\"",
    "Rename file" : "Renombrar archivo",
    "Folder" : "Carpeta",
    "Pending" : "Pendiente",
    "Unknown date" : "Fecha desconocida",
    "Clear filter" : "Limpiar filtro",
    "Modified" : "Modificado",
    "Search everywhere" : "Buscar en todas partes",
    "Type" : "Tipo",
    "Active filters" : "Filtros activos",
    "Remove filter" : "Quitar filtro",
    "Total rows summary" : "Resumen de filas totales",
    "Toggle selection for all files and folders" : "Alternar selección para todos los archivos y carpetas",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Actions" : "Acciones",
    "(selected)" : "(seleccionado)",
    "List of files and folders." : "Lista de archivos y carpetas.",
    "Column headers with buttons are sortable." : "Las columnas con botones en la cabecera son ordenables.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Esta lista no se muestra completamente por motivos de rendimiento. Los archivos se mostrarán a medida que navega por la lista.",
    "File not found" : "Archivo no encontrado",
    "{usedQuotaByte} used" : "{usedQuotaByte} utilizados",
    "{used} of {quota} used" : "{used} de {quota} usados",
    "{relative}% used" : "{relative}% utilizado",
    "Could not refresh storage stats" : "No fue posible actualizar las estadísticas de almacenamiento",
    "Your storage is full, files can not be updated or synced anymore!" : "Su espacio está lleno. ¡Los archivos ya no se pueden actualizar o sincronizar!",
    "Storage information" : "Información de almacenamiento",
    "Storage quota" : "Cuota de almacenamiento",
    "New folder" : "Carpeta nueva",
    "Create new folder" : "Crear nueva carpeta",
    "This name is already in use." : "Este nombre ya está en uso.",
    "Create" : "Crear",
    "Refresh" : "Actualizar",
    "Limit" : "Límite",
    "Fill template fields" : "Rellenar los campos de la plantilla",
    "Submit" : "Enviar",
    "Choose a file or folder to transfer" : "Elegir archivo o carpeta para transferir",
    "Transfer" : "Transferir",
    "Transfer {path} to {userid}" : "Transferir {path} a {userid}",
    "Invalid path selected" : "Ruta seleccionada no válida.",
    "Unknown error" : "Se presentó un error desconocido",
    "Ownership transfer request sent" : "Enviada la solicitud de transferencia de propiedad",
    "Cannot transfer ownership of a file or folder you do not own" : "No puede transferir la propiedad de un archivo o directorio del cual no es propietario",
    "Transfer ownership of a file or folder" : "Transferir la propiedad de un archivo o carpeta",
    "Choose file or folder to transfer" : "Elegir archivo o carpeta para transferir",
    "Change" : "Cambiar",
    "New owner" : "Nuevo propietario",
    "Remove extension" : "Remover extensión",
    "Change file extension" : "Cambiar extensión de archivo",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Cambiar la extensión del archivo de \"{old}\" a \"{new}\" podría volver al archivo inaccesible.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Remover la extensión \"{old}\" podría volver al archivo inaccesible.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Añadir la extensión de archivo \"{new}\" podría volver al archivo inaccesible.",
    "Select file or folder to link to" : "Seleccionar archivo o carpeta para enlazar.",
    "Choose {file}" : "Elegir {file}",
    "Clipboard is not available" : "El portapapeles no está disponible",
    "Files settings" : "Configuración de archivos",
    "General" : "General",
    "All files" : "Todos los archivos",
    "Personal files" : "Archivos personales",
    "Sort favorites first" : "Ordenar los favoritos primero",
    "Sort folders before files" : "Ordenar carpetas antes que archivos",
    "Appearance" : "Apariencia",
    "Show hidden files" : "Mostrar archivos ocultos",
    "Crop image previews" : "Recortar la previsualización de las imágenes",
    "Additional settings" : "Configuraciones adicionales",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV URL",
    "Copy" : "Copiar",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Rename" : "Renombrar",
    "Delete" : "Borrar",
    "Manage tags" : "Administrar etiquetas",
    "Selection" : "Selección",
    "Deselect all" : "Deseleccionar todo",
    "Navigation" : "Navegación",
    "View" : "Ver",
    "Toggle grid view" : "Vista de cuadrícula",
    "Share" : "Compartir",
    "Shared by link" : "Compartido por liga",
    "Shared" : "Compartido",
    "Switch to list view" : "Cambiar a la vista de lista",
    "Switch to grid view" : "Cambiar a la vista de cuadrícula",
    "Upload was cancelled by user" : "La subida fue cancelada por el usuario",
    "Not enough free space" : "No cuentas con suficiente espacio libre",
    "Operation is blocked by access control" : "Esta operación está bloqueada por el control de accesos",
    "Error during upload: {message}" : "Error durante la subida: {message}",
    "Error during upload, status code {status}" : "Error durante la carga, código de estado {status}",
    "Unknown error during upload" : "Error desconocido durante la carga",
    "Loading current folder" : "Cargando la carpeta actual",
    "Retry" : "Reintentar",
    "No files in here" : "No hay archivos aquí",
    "Upload some content or sync with your devices!" : "¡Carga algún contenido o sincroniza con tus dispositivos!",
    "Go back" : "Regresar",
    "Views" : "Vistas",
    "You" : "Usted",
    "Shared multiple times with different people" : "Compartido múltiples veces con diferentes personas",
    "Error while loading the file data" : "Error al cargar los datos del archivo",
    "Owner" : "Propietario",
    "Remove from favorites" : "Eliminar de favoritos",
    "Add to favorites" : "Agregar a favoritos",
    "Tags" : "Etiquetas",
    "Your files" : "Sus archivos",
    "Open in files" : "Abrir en archivos",
    "File cannot be accessed" : "No se puede acceder al archivo",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "El archivo no fue encontrado o no tiene permisos para verlo. Solicite al remitente que lo comparta.",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permitir restringir los nombres de archivos para asegurar que los archivos se puedan sincronizar con todos los clientes. Por defecto, se permiten todos los nombres de archivos válidos en POSIX (por ejemplo, Linux o macOS).",
    "Files compatibility" : "Compatibilidad de archivos",
    "Enforce Windows compatibility" : "Imponer la compatibilidad de Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Esto bloqueará los nombres de archivos inválidos en sistemas Windows, tales como usar nombres reservados o caracteres especiales. Pero no impondrá la compatibilidad del uso de mayúsculas y minúsculas.",
    "Blank" : "Vacío",
    "Unable to create new file from template" : "No se ha podido crear un nuevo archivo desde la plantilla",
    "Pick a template for {name}" : "Elija una plantilla para {name}",
    "Create a new file with the selected template" : "Crear un nuevo archivo con la plantilla seleccionada",
    "Creating file" : "Creando el archivo",
    "Leave this share" : "Dejar este recurso compartido",
    "Leave these shares" : "Dejar estos recursos compartidos",
    "Disconnect storage" : "Desconectar almacenamiento",
    "Disconnect storages" : "Desconectar almacenamientos",
    "Delete permanently" : "Eliminar permanentemente",
    "Delete and unshare" : "Eliminar y dejar de compartir",
    "Delete file" : "Eliminar archivo",
    "Delete files" : "Eliminar archivos",
    "Delete folder" : "Eliminar carpeta",
    "Delete folders" : "Eliminar carpetas",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Está a punto de eliminar {count} elemento permanentemente.","Está a punto de eliminar {count} elementos permanentemente.","Está a punto de eliminar {count} elementos permanentemente."],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Está a punto de eliminar {count} elemento.","Está a punto de eliminar {count} elementos.","Está a punto de eliminar {count} elementos."],
    "Confirm deletion" : "Confirmar eliminación",
    "Cancel" : "Cancelar",
    "Download" : "Descargar",
    "Destination is not a folder" : "El destino no es una carpeta",
    "This file/folder is already in that directory" : "Este archivo/carpeta ya está en ese directorio",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "No puede mover un archivo/carpeta a sí mismo o a una subcarpeta de sí mismo",
    "(copy)" : "(copiar)",
    "(copy %n)" : "(copiar %n)",
    "A file or folder with that name already exists in this folder" : "Un archivo o carpeta con ese nombre ya existe en esta carpeta",
    "The files are locked" : "Los archivos están bloqueados",
    "The file does not exist anymore" : "El archivo ya no existe",
    "Choose destination" : "Elegir destino",
    "Copy to {target}" : "Copiar a {target}",
    "Move to {target}" : "Mover a {target}",
    "Move" : "Mover",
    "Move or copy operation failed" : "La operación de mover o copiar falló",
    "Move or copy" : "Mover o copiar",
    "Open folder {displayName}" : "Abrir carpeta {displayName}",
    "Open in Files" : "Abrir en Archivos",
    "Failed to redirect to client" : "Fallo al redirigir al cliente",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "El archivo se abrirá ahora en tu dispositivo. Si esto no ocurre, por favor verifica que hayas instalado la aplicación de escritorio.",
    "Retry and close" : "Reintentar y cerrar",
    "Details" : "Detalles",
    "View in folder" : "Ver en la carpeta",
    "Today" : "Hoy",
    "Last 7 days" : "Últimos 7 días",
    "Last 30 days" : "Últimos 30 días",
    "This year ({year})" : "Este año ({year})",
    "Last year ({year})" : "El año pasado ({year})",
    "Documents" : "Documentos",
    "Spreadsheets" : "Hojas de cálculo",
    "Presentations" : "Presentaciones",
    "PDFs" : "PDFs",
    "Folders" : "Carpetas",
    "Audio" : "Audio",
    "Images" : "Imágenes",
    "Videos" : "Videos",
    "Created new folder \"{name}\"" : "Nueva carpeta \"{name}\" creada",
    "Unable to initialize the templates directory" : "No se ha podido iniciar la carpeta de plantillas",
    "Create templates folder" : "Crear la carpeta de plantillas",
    "Templates" : "Plantillas",
    "New template folder" : "Nueva carpeta de plantillas",
    "In folder" : "En la carpeta",
    "Search in folder: {folder}" : "Buscar en la carpeta: {folder}",
    "One of the dropped files could not be processed" : "Uno de los archivos arrastrados no puede ser procesado",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Su navegador no soporta la API de Sistema de archivos. Los directorios no se cargarán",
    "No files to upload" : "No hay archivos para subir",
    "Unable to create the directory {directory}" : "No se pudo crear el directorio {directory}",
    "Some files could not be uploaded" : "No se pudieron subir algunos archivos",
    "Files uploaded successfully" : "Archivo subido exitosamente",
    "No files to process" : "No hay archivos a procesar",
    "Some files could not be copied" : "Algunos archivos no se pudieron copiar",
    "Some files could not be moved" : "Algunos archivos no se pudieron mover",
    "Files copied successfully" : "Archivos copiados exitosamente",
    "Files moved successfully" : "Archivos movidos exitosamente",
    "Conflicts resolution skipped" : "Resolución de conflictos omitida",
    "Upload cancelled" : "Subida cancelada",
    "Could not rename \"{oldName}\", it does not exist any more" : "No se pudo renombrar \"{oldName}\", ya no existe.",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{newName}\" ya está en uso en la carpeta \"{dir}\". Por favor, elija un nombre diferente.",
    "Could not rename \"{oldName}\"" : "No se pudo renombrar \"{oldName}\"",
    "This operation is forbidden" : "Esta operación está prohibida",
    "Storage is temporarily not available" : "El almacenamiento no está disponible temporalmente ",
    "Unexpected error: {error}" : "Error inesperado: {error}",
    "_%n file_::_%n files_" : ["%n archivo","%n archivos","%n archivos"],
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas","%n carpetas"],
    "Filename must not be empty." : "El nombre de archivo no puede estar vacío.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" no está permitido en el nombre de archivo.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" es un nombre reservado y no se permite en el nombre de archivo.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" no es un tipo de archivo permitido.",
    "Filenames must not end with \"{extension}\"." : "El nombre de archivo no puede terminar con \"{extension}\".",
    "List of favorite files and folders." : "Lista de archivos y carpetas favoritos",
    "No favorites yet" : "Aún no hay favoritos",
    "Files and folders you mark as favorite will show up here" : "Los archivos y carpetas que marques como favoritos se mostrarán aquí. ",
    "List of your files and folders." : "Lista de sus archivos y carpetas.",
    "List of your files and folders that are not shared." : "Lista de sus archivos y carpetas que no están compartidos.",
    "No personal files found" : "No se encontraron archivos personales",
    "Files that are not shared will show up here." : "Aquí aparecerán los archivos y carpetas que no ha compartido.",
    "Recent" : "Reciente",
    "List of recently modified files and folders." : "Lista de archivos y carpetas modificados recientemente.",
    "No recently modified files" : "No hay archivos modificados recientemente",
    "Files and folders you recently modified will show up here." : "Los archivos y carpetas que ha modificado recientemente aparecerán aquí.",
    "Search" : "Buscar",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Select all" : "Seleccionar todo",
    "Upload too large" : "La carga es demasido grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que estás intentando cargar sobrepasan el tamaño máximo permitido para la carga de archivos en este servidor.",
    "Upload (max. %s)" : "Cargar (max. %s)",
    "\"{displayName}\" batch action executed successfully" : "La acción en lote \"{displayName}\" se ejecutó exitosamente",
    "\"{displayName}\" action failed" : "La acción \"{displayName}\" falló",
    "\"{displayName}\" action executed successfully" : "La acción \"{displayName}\" se ejecutó correctamente",
    "WebDAV URL copied to clipboard" : "WebDAV URL copiada al portapapeles",
    "Enable the grid view" : "Habilitar la vista de cuadrícula",
    "Enable folder tree" : "Habilitar el árbol de carpetas",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Use this address to access your Files via WebDAV" : "Use esta dirección para acceder a tus archivos vía WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si ha habilitado 2FA, debe crear y utilizar una nueva contraseña de aplicación haciendo clic aquí.",
    "Deletion cancelled" : "Eliminación cancelada",
    "Edit locally" : "Editar localmente",
    "Moving \"{source}\" to \"{destination}\" …" : "Moviendo \"{source}\" a \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Copiando \"{source}\" a \"{destination}\" …",
    "Move cancelled" : "Movimiento cancelado",
    "Cancelled move or copy of \"{filename}\"." : "Se canceló la operación de mover o copiar de \"{filename}\".",
    "Cancelled move or copy operation" : "Se canceló la operación de mover o copiar",
    "Open details" : "Abrir detalles",
    "Photos and images" : "Fotos e imágenes",
    "New folder creation cancelled" : "Creación de nueva carpeta cancelada",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verfica las bitácoras o contacta al administrador",
    "All folders" : "Todas las carpetas"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
